@@ -2,7 +2,7 @@
  * Dale P. Smith and wmSun by Mike Henderson. Additional patches for
  * gkrellm 2.0 and Windows support from Bill Nalen.
  *
- * $Id: CalcEphem.c,v 1.11 2004/03/06 06:33:48 kvh009 Exp $
+ * $Id: CalcEphem.c,v 1.12 2006/03/17 13:29:51 nwalsh Exp $
  *
  */
 #ifdef HAVE_CONFIG_H
@@ -12,8 +12,6 @@
 #include "CalcEphem.h"
 #include "Moon.h"
 
-static gdouble jd();
-
 /* Set this time before calling any of these functions! */
 /* This arrangement allows the caller to change the effective date. */
 /* This can't be static... */
@@ -44,7 +42,7 @@ static gdouble kepler(gdouble M, gdouble e)
  *  Compute the Julian Day number for the given date.
  *  Julian Date is the number of days since noon of Jan 1 4713 B.C.
  */
-static gdouble jd(gint ny, gint nm, gint nd, gdouble UT)
+gdouble jd(gint ny, gint nm, gint nd, gdouble UT)
 {
    gdouble A, B, C, D, JD, day;
 
@@ -67,7 +65,7 @@ static gdouble jd(gint ny, gint nm, gint nd, gdouble UT)
       B = 0.0;
    }
 
-   if (ny < DBL_EPSILON)
+   if (ny < 0)
    {
       C = (gint) ((365.25 * (gdouble) ny) - 0.75);
    }
@@ -82,16 +80,16 @@ static gdouble jd(gint ny, gint nm, gint nd, gdouble UT)
    return (JD);
 }
 
-static gdouble hour24(gdouble hour)
+gdouble hour24(gdouble hour)
 {
    gint n;
 
-   if (hour < DBL_EPSILON)
+   if (hour < 0)
    {
       n = (gint) (hour / 24.0) - 1;
       return (hour - n * 24.0);
    }
-   else if ( (hour - 24.0) > DBL_EPSILON)
+   else if ( hour >= 24.0)
    {
       n = (gint) (hour / 24.0);
       return (hour - n * 24.0);
@@ -102,18 +100,18 @@ static gdouble hour24(gdouble hour)
    }
 }
 
-static gdouble angle2pi(gdouble angle)
+gdouble angle2pi(gdouble angle)
 {
    gint n;
    gdouble a;
    a = 2.0 * M_PI;
 
-   if ( angle < DBL_EPSILON)
+   if ( angle < 0)
    {
       n = (gint) (angle / a) - 1;
       return (angle - n * a);
    }
-   else if ( (angle - a) > DBL_EPSILON)
+   else if (angle >= a)
    {
       n = (gint) (angle / a);
       return (angle - n * a);
@@ -128,12 +126,12 @@ static gdouble angle360(gdouble angle)
 {
    gint n;
 
-   if (angle < DBL_EPSILON)
+   if (angle < 0)
    {
       n = (gint) (angle / 360.0) - 1;
       return (angle - n * 360.0);
    }
-   else if ( (angle - 360.0) > DBL_EPSILON)
+   else if (angle >= 360.0)
    {
       n = (gint) (angle / 360.0);
       return (angle - n * 360.0);
@@ -165,7 +163,7 @@ double *xe, double *ye, double *z1, double *z2, int *nz)
       *z2 = *xe+dx;
       if (fabs(*z1) <= 1.0) *nz += 1;
       if (fabs(*z2) <= 1.0) *nz += 1;
-      if ( (*z1 + 1.0) < DBL_EPSILON) *z1 = *z2;
+      if (*z1 <= -1.0) *z1 = *z2;
    }
 
    return;
@@ -190,7 +188,7 @@ static double SinH(int year, int month, int day, double UT, CTrans *c)
    X = cos(L); Y = cosEPS*SL; Z = sinEPS*SL; RHO = sqrt(1.0-Z*Z);
    DEC_Sun = atan2(Z, RHO);
    RA_Sun = (48.0/P2)*atan(Y/(X+RHO));
-   if (RA_Sun < DBL_EPSILON) RA_Sun += 24.0;
+   if (RA_Sun < 0) RA_Sun += 24.0;
 
    RA_Sun = RA_Sun*15.0*RadPerDeg;
 
@@ -252,7 +250,7 @@ static void SunRise(int year, int month, int day, gdouble UT, CTrans *c, int deb
          case 0:
             break;
          case 1:
-            if (ym < DBL_EPSILON)
+            if (ym < 0)
             {
                UTRise = UT + z1;
                Rise = 1;
@@ -264,7 +262,7 @@ static void SunRise(int year, int month, int day, gdouble UT, CTrans *c, int deb
             }
             break;
          case 2:
-            if (ye < DBL_EPSILON)
+            if (ye < 0)
             {
                UTRise = UT + z2;
                UTSet = UT + z1;
@@ -466,7 +464,7 @@ void sunclock_CalcEphem(glong date, gdouble UT, CTrans * c, int debug)
    c->A_moon = DegPerRad * atan2(y, x) + 180.0;
    c->h_moon = DegPerRad * asin(z);
    /*	c->Visible = (c->h_moon < 0.0) ? 0 : 1;*/
-   if (c->h_moon < DBL_EPSILON) c->Visible = 0;
+   if (c->h_moon < 0) c->Visible = 0;
    else c->Visible = 1;
 
    if (debug)
