@@ -4,7 +4,7 @@
 /* Copyright (C) 2001, Norman Walsh. Derived from gkrellmoon by
  * Dale P. Smith and wmSun by Mike Henderson
  *
- * $Id: CalcEphem.h,v 1.4 2004/03/06 06:33:48 kvh009 Exp $
+ * $Id: CalcEphem.h,v 1.5 2006/03/17 13:29:51 nwalsh Exp $
  *
  */
 
@@ -19,7 +19,6 @@
 #define DegPerRad       57.29577951308232087680
 #define RadPerDeg        0.01745329251994329576
 
-
 typedef struct Vector {
 	gdouble x;
 	gdouble y;
@@ -81,5 +80,8 @@ typedef struct CTrans {
 } CTrans;
 
 void sunclock_CalcEphem(glong date, gdouble UT, CTrans * c, int debug);
+gdouble hour24(gdouble hour);
+gdouble jd(gint ny, gint nm, gint nd, gdouble UT);
+gdouble angle2pi(gdouble angle);
 
 #endif				/* CALC_EPHEM_H */
