@@ -3,7 +3,7 @@
  * Copyright (C) 2001, 2002, 2003 Norman Walsh. Derived from gkrellmoon by
  * Dale P. Smith and wmSun by Mike Henderson
  *
- * $Id: gkrellsun.c,v 1.59 2004/06/06 13:34:21 nwalsh Exp $
+ * $Id: gkrellsun.c,v 1.64 2006/03/17 13:29:51 nwalsh Exp $
  *
  */
 #if !defined(WIN32)
@@ -68,9 +68,9 @@ extern void pango_font_description_free (/*@owned@*/PangoFontDescription *);
 
 #define STYLE_NAME "sun"
 #define PLUGIN_CONFIG_KEYWORD   "sun"
-#define SUNCLOCK_MAJOR_VERSION  0
-#define SUNCLOCK_MINOR_VERSION  12
-#define SUNCLOCK_PATCH_VERSION  1
+#define SUNCLOCK_MAJOR_VERSION  1
+#define SUNCLOCK_MINOR_VERSION  0
+#define SUNCLOCK_PATCH_VERSION  0
 
 #define NUMBER_OF_SUNS  2
 #define NUMBER_OF_TIMES 3
@@ -125,6 +125,7 @@ typedef struct
    int showMiniMoon;
    int whichSun;
    int sunmoon_toggle_minutes;
+   int autoMoon;	      /* NZ to show moon at night */
    int debug;
 } Options;
 
@@ -139,6 +140,7 @@ static int baseX = 0;
 static int baseY = 0;
 
 static gint  panel_view = 0;  /* 0 = sun; 1 = moon */
+static gint  inDaylight = 1;
 
 static GtkWidget *longitude_spin_button = NULL;
 static GtkWidget *latitude_spin_button = NULL;
@@ -148,6 +150,7 @@ static GtkWidget *showPath_button = NULL;
 static GtkWidget *show90Path_button = NULL;
 static GtkWidget *showMiniMoon_button = NULL;
 static GtkWidget *showETA_button = NULL;
+static GtkWidget *autoMoon_button = NULL;
 static GtkWidget *debug_button = NULL;
 static GtkWidget *long_E_radio_button = NULL;
 static GtkWidget *long_W_radio_button = NULL;
@@ -205,6 +208,7 @@ static GtkTooltips *tooltip;
 static GkrellmTicks *pGK;
 
 #include "CalcEphem.h"
+#include "MoonRise.h"
 
 typedef struct CTrans SunData;
 
@@ -214,12 +218,12 @@ struct _Sun
    SunData data;
 };
 
-extern long CurrentGMTTime;
-/*long CurrentGMTTime = 0;*/
+extern time_t CurrentGMTTime;
 static Sun sununit;
 
 static gchar *sun_data_dir;
 
+static double dayLength(Sun *sun);
 static void load_sun_data(void);
 static void save_sun_data(void);
 static void update_tooltip(Sun *sun);
@@ -230,13 +234,14 @@ static void update_sun_data(Sun * sun)
    gdouble local_std_time, univ_time, eot;
    glong date;
    gint day_of_month, month, year;
+   gdouble s_set;
 
-   CurrentGMTTime = (long) time(NULL);
+   CurrentGMTTime = (time_t) time(NULL);
 
-   time_struc = gmtime(&(time_t)CurrentGMTTime);
+   time_struc = gmtime(&CurrentGMTTime);
    /* It may return NULL when the year does not fit into an integer.*/
    if (time_struc == NULL) {
-      g_message("Error:  gmtime returned NULL\n"); exit(EXIT_FAILURE);
+      g_message(_("Error:  gmtime returned NULL\n")); exit(EXIT_FAILURE);
    }
    univ_time =
       time_struc->tm_hour + time_struc->tm_min / 60.0 +
@@ -254,13 +259,13 @@ static void update_sun_data(Sun * sun)
 
    if (options.debug == TRUE)
    {
-      g_message("gkrellsun debug: GMT date = %04d-%02d-%02d (%ld)\n",
+      g_message(_("gkrellsun debug: GMT date = %04d-%02d-%02d (%ld)\n"),
          year, month, day_of_month, date);
    }
 
-   time_struc = localtime(&(time_t)CurrentGMTTime);
+   time_struc = localtime(&CurrentGMTTime);
    if (time_struc == NULL) {
-      g_message("Error: localtime returned NULL\n"); exit(EXIT_FAILURE);
+      g_message(_("Error: localtime returned NULL\n")); exit(EXIT_FAILURE);
    }
    local_std_time =
       time_struc->tm_hour + time_struc->tm_min / 60.0 +
@@ -268,7 +273,7 @@ static void update_sun_data(Sun * sun)
 
    if (options.debug == TRUE)
    {
-      g_message("gkrellsun: local date = %04d-%02d-%02d\n",
+      g_message(_("gkrellsun: local date = %04d-%02d-%02d\n"),
          time_struc->tm_year + 1900,
          time_struc->tm_mon + 1,
          time_struc->tm_mday);
@@ -279,8 +284,8 @@ static void update_sun_data(Sun * sun)
 
    if (options.debug == TRUE)
    {
-      g_message("gkrellsun: latitude  = %d\n", options.latitude);
-      g_message("gkrellsun: longitude = %d\n", options.longitude);
+      g_message(_("gkrellsun: latitude  = %d\n"), options.latitude);
+      g_message(_("gkrellsun: longitude = %d\n"), options.longitude);
    }
 
    sunclock_CalcEphem(date, univ_time, &sun->data, options.debug);
@@ -289,27 +294,24 @@ static void update_sun_data(Sun * sun)
    sun->data.LST = local_std_time;
    sun->data.LMT = univ_time - sun->data.Glon / 15.0;
 
-   /* splint - Two real (float, double, or long double) values are compared directly using a
-  C primitive. This may produce unexpected results since floating point
-  representations are inexact. Instead, compare the difference to FLT_EPSILON */
-   if (sun->data.LMT < DBL_EPSILON)  /* < 0.0 */
+   if (sun->data.LMT < 0)
       sun->data.LMT += 24.0;
-   if ((sun->data.LMT - 24.0) > DBL_EPSILON) /* > 24.0 */
+   else if (sun->data.LMT >= 24.0)
       sun->data.LMT -= 24.0;
 
    if (options.debug == TRUE)
    {
-      g_message("gkrellsun: sun LST (Local Standard Time) = %6.2f\n", sun->data.LST);
-      g_message("gkrellsun: sun LMT (Local Mean Time)     = %6.2f\n", sun->data.LMT);
-      g_message("gkrellsun: sun Rise = %d\n", sun->data.Rise);
-      g_message("gkrellsun: sun Set  = %d\n", sun->data.Set);
-      g_message("gkrellsun: sun LTRise = %6.2f\n", sun->data.LTRise);
-      g_message("gkrellsun: sun LTSet  = %6.2f\n", sun->data.LTSet);
-      g_message("gkrellsun: A_moon = %6.2f\n", sun->data.A_moon);
-      g_message("gkrellsun: h_moon = %6.2f\n", sun->data.h_moon);
-      g_message("gkrellsun: moon age = %6.2f\n", sun->data.MoonAge);
-      g_message("gkrellsun: SinGlat = %6.2f\n", sun->data.SinGlat);
-      g_message("gkrellsun: CosGlat = %6.2f\n", sun->data.CosGlat);
+      g_message(_("gkrellsun: sun LST (Local Standard Time) = %6.2f\n"), sun->data.LST);
+      g_message(_("gkrellsun: sun LMT (Local Mean Time)     = %6.2f\n"), sun->data.LMT);
+      g_message(_("gkrellsun: sun Rise = %d\n"), sun->data.Rise);
+      g_message(_("gkrellsun: sun Set  = %d\n"), sun->data.Set);
+      g_message(_("gkrellsun: sun LTRise = %6.2f\n"), sun->data.LTRise);
+      g_message(_("gkrellsun: sun LTSet  = %6.2f\n"), sun->data.LTSet);
+      g_message(_("gkrellsun: A_moon = %6.2f\n"), sun->data.A_moon);
+      g_message(_("gkrellsun: h_moon = %6.2f\n"), sun->data.h_moon);
+      g_message(_("gkrellsun: moon age = %6.2f\n"), sun->data.MoonAge);
+      g_message(_("gkrellsun: SinGlat = %6.2f\n"), sun->data.SinGlat);
+      g_message(_("gkrellsun: CosGlat = %6.2f\n"), sun->data.CosGlat);
    }
 
    /* eot is the equation of time. gmst is Greenwich Sidereal
@@ -329,17 +331,24 @@ static void update_sun_data(Sun * sun)
 
    eot = 12.0 - univ_time + sun->data.gmst - sun->data.RA_sun / 15.0;
 
-   if (eot < DBL_EPSILON)
+   if (eot < 0)
       eot += 24.0;
-   if ((eot - 24.0) > DBL_EPSILON)       /* (eot > 24.0) */
+   else if (eot >= 24.0)
       eot -= 24.0;
 
    sun->data.LAT = sun->data.LMT + eot;
-   if ((sun->data.LAT - 0.0) < DBL_EPSILON)  /* < 0.0) */
+   if (sun->data.LAT < 0.0)
       sun->data.LAT += 24.0;
-   if ((sun->data.LAT - 24.0) > DBL_EPSILON) /* > 24.0)*/
+   else if (sun->data.LAT >= 24.0)
       sun->data.LAT -= 24.0;
 
+   s_set = sun->data.LTRise + dayLength(sun);
+
+   inDaylight = (sun->data.LST >= sun->data.LTRise
+		 && sun->data.LST <= s_set
+		 && sun->data.Rise
+		 && sun->data.Set);
+
    update_tooltip(sun);
 }
 
@@ -459,7 +468,7 @@ static double percentOfDay(Sun *sun, double tod) {
 static double percentOfAltitude(Sun *sun, double tod)
 {
    double dayperc = percentOfDay(sun, tod);
-   if ((dayperc - 0.5) > DBL_EPSILON)     /* > 0.5) */
+   if (dayperc >= 0.5)
    {
       return 1.0 - dayperc;
    }
@@ -472,7 +481,7 @@ static double percentOfAltitude(Sun *sun, double tod)
 static double altitudeAtNoon(Sun *sun)
 {
    double altnoon = 90.0 - sun->data.Glat + sun->data.DEC_sun;
-   if ((altnoon - 90.0) > DBL_EPSILON)    /* > 90) */
+   if (altnoon > 90.0)
    {
       altnoon = 90.0 - (altnoon - 90.0);
    }
@@ -495,23 +504,23 @@ static void drawSun(Sun *sun)
       if (sun->data.Rise && sun->data.Set)
       {
          /* If the sun rises and sets today... */
-         if (((sun->data.LST - sun->data.LTRise) < DBL_EPSILON) ||
-            ((sun->data.LST - s_set) > DBL_EPSILON))
+         if (sun->data.LST < sun->data.LTRise ||
+            sun->data.LST >= s_set)
          {
             image_number = 1;
          }
          else
          {
             image_number = 2;
-            if ((perc - 0.25) > DBL_EPSILON) image_number = 3;
-            if ((perc - 0.50) > DBL_EPSILON) image_number = 4;
-            if ((perc - 0.75) > DBL_EPSILON) image_number = 5;
+            if (perc > 0.25) image_number = 3;
+            if (perc > 0.50) image_number = 4;
+            if (perc > 0.75) image_number = 5;
          }
       }
       else if (!sun->data.Rise && sun->data.Set)
       {
          /* If the sun doesn't rise but it does set... */
-         if ((sun->data.LST - sun->data.LTRise) > DBL_EPSILON)
+         if (sun->data.LST >= sun->data.LTRise)
          {
             image_number = 1;
          }
@@ -523,7 +532,7 @@ static void drawSun(Sun *sun)
       else if (sun->data.Rise && !sun->data.Set)
       {
          /* If the sun rises but it doesn't set... */
-         if ((sun->data.LST - sun->data.LTRise) < DBL_EPSILON)
+         if (sun->data.LST <= sun->data.LTRise)
          {
             image_number = 1;
          }
@@ -664,8 +673,8 @@ static void computePath(Sun *sun, GkrellmDecal **path, double maxAlt)
    if (options.debug) {
       printTOD("Rise: ", sun->data.LTRise);
       printTOD("Set: ", sun->data.LTSet);
-      g_message ("At Noon: %6.2f\n", altitudeAtNoon(sun));
-      g_message ("Max: %6.2f\n", maxAlt);
+      g_message(_("At Noon: %6.2f\n"), altitudeAtNoon(sun));
+      g_message(_("Max: %6.2f\n"), maxAlt);
    }
 
    for (count = 0; count < PATH_COUNT; count++)
@@ -744,12 +753,12 @@ sun_update_plugin()
    int starImage = 0;
    double eta = 0;
    double s_set;
-   int inDaylight = 0;
    int timeXOffsets, sun, time;
    struct tm   *t;
+   int showMoon;
 
    /* If the theme has changed, redraw will be 1 */
-   /* Currently, the plugin is updated on the 5 minute tick. */
+   /* Currently, the plugin is updated on the 1 minute tick. */
    if (!(redraw || pGK->minute_tick))
       return;
 
@@ -758,12 +767,8 @@ sun_update_plugin()
    if (options.sunmoon_toggle_minutes > 0)
       if (!redraw && (t->tm_min % options.sunmoon_toggle_minutes) == 0) {
          panel_view = 1 - panel_view;  /* Toggle between SUN/MOON */
-         redraw = 1;                   /* Force redraw */
       }
 
-   if (!(redraw || ((t->tm_min % 5) ==0) ))
-      return;
-
 /*   printf("Update/Redrawing plugin: redraw=%d, minute_tick=%d, 5_minute_tick=%d\n", redraw, pGK->minute_tick, (t->tm_min % 5) == 0); */
 
    redraw = 0;
@@ -776,7 +781,11 @@ sun_update_plugin()
 		 && sununit.data.Rise
 		 && sununit.data.Set);
 
-   if (panel_view == 0) {     /* Sun is visiable */
+   showMoon = panel_view;
+   if (options.autoMoon  &&  !inDaylight)
+      showMoon = !showMoon;
+
+   if (!showMoon) {            /* Sun is visible */
       gkrellm_make_decal_invisible(panel, moon_full);
       sun = options.whichSun;
       for (time = 0; time < NUMBER_OF_TIMES; time++)
@@ -784,7 +793,7 @@ sun_update_plugin()
       gkrellm_make_decal_visible(panel, star);
       drawSun(&sununit);
       drawMoon(&sununit,options.showMiniMoon);
-   } else {                   /* Moon is visiable */
+   } else {                   /* Moon is visible */
       gkrellm_make_decal_visible(panel, moon_full);
       gkrellm_make_decal_invisible(panel, uvsun);
       gkrellm_make_decal_invisible(panel, osun);
@@ -812,14 +821,14 @@ sun_update_plugin()
 
    if (options.showETA == TRUE)       /* Allow all suns to show ETA */
    {
-      if ((sununit.data.LST - sununit.data.LTRise) < DBL_EPSILON)
+      if (sununit.data.LST < sununit.data.LTRise)
       {
          eta = sununit.data.LTRise - sununit.data.LST;
          drawTextTime(eta, 1, TIME_ETA, 1);
       }
 
-      if (((sununit.data.LST - sununit.data.LTRise) >= DBL_EPSILON) &&
-	  ((sununit.data.LST - s_set) < DBL_EPSILON))
+      if (sununit.data.LST >= sununit.data.LTRise &&
+	  sununit.data.LST < s_set)
       {
          eta = s_set - sununit.data.LST;
          drawTextTime(eta, 1, TIME_ETA, 1);
@@ -860,7 +869,7 @@ sun_update_plugin()
       image_y_offset = SUN_INNER_HEIGHT - (pos_y + baseY) - SUN_INNER_YOFS - STAR_YOFS;
 
       if (options.debug)
-         g_message ("Star at: (%d,%d) %d\n", image_x_offset, image_y_offset, pos_y);
+         g_message (_("Star at: (%d,%d) %d\n"), image_x_offset, image_y_offset, pos_y);
 
       gkrellm_move_decal(panel, star, image_x_offset, image_y_offset);
       starImage = 1;
@@ -885,6 +894,35 @@ sun_update_plugin()
    gkrellm_draw_panel_layers(panel);
 }
 
+static void show_moon_riseset_time(Sun *sun, gint offset, char *dayName,
+  GString *mboxes)
+{
+    gdouble rise, set;
+    gint oldDay = sun->data.day;
+
+    sun->data.day += offset;
+    MoonRise(&sun->data, &rise, &set);
+    sun->data.day = oldDay;
+
+    (void)g_string_append_printf(mboxes, "%s: ", dayName);
+
+    /* Since we only report to the minute, round to nearest minute */
+    rise += 0.5 / 60;
+    set += 0.5 / 60;
+
+    if (abs(rise) > 24.0)
+	(void)g_string_append_printf(mboxes, "no rise ");
+    else
+	(void)g_string_append_printf(mboxes, "%02d:%02d ", (gint)rise,
+	  (gint)(rise * 60) % 60);
+
+    if (abs(set) > 24.0)
+	(void)g_string_append_printf(mboxes, "no set\n");
+    else
+	(void)g_string_append_printf(mboxes, "%02d:%02d\n", (gint)set,
+	  (gint)(set * 60) % 60);
+}
+
 static void
 update_tooltip(Sun *sun)
 {
@@ -896,6 +934,7 @@ update_tooltip(Sun *sun)
    int         ampm_digit;
    char        EW, NS;
    int         dlat, dlon;
+   int	       showMoon;
    gint moonphase;
 
    if (tooltip == NULL)
@@ -920,15 +959,19 @@ update_tooltip(Sun *sun)
    (void)g_string_append_printf(mboxes, _("Location: %d%c %d%c\n"),
 				dlat, NS, dlon, EW);
 
-   if (panel_view == 0) {     /* Sun */
+   showMoon = panel_view;
+   if (options.autoMoon  &&  !inDaylight)
+      showMoon = !showMoon;
+
+   if (!showMoon) {           /* Sun */
       /* Determine clock format */
       if( options.clock24 )
       {
-         strncpy( time_format, "%02d:%02d", sizeof( time_format ) );
+         g_strlcpy( time_format, "%02d:%02d", sizeof( time_format ) );
       }
       else
       {
-         strncpy( time_format, "%d:%02d%c", sizeof( time_format ) );
+         g_strlcpy( time_format, "%d:%02d%c", sizeof( time_format ) );
       }
 
       /* Sun rise ... */
@@ -939,7 +982,7 @@ update_tooltip(Sun *sun)
 
          ampm_digit = clock_ampm( H );
          H = clock_adjust_hour( H );
-         (void)snprintf( format_string, sizeof( format_string ), 
+         (void)g_snprintf( format_string, sizeof( format_string ), 
             _("Sunrise: %s\n"), time_format );
 
          (void)g_string_append_printf(mboxes, format_string, H, M,
@@ -958,7 +1001,7 @@ update_tooltip(Sun *sun)
 
          ampm_digit = clock_ampm( H );
          H = clock_adjust_hour( H );
-         (void)snprintf( format_string, sizeof( format_string ), 
+         (void)g_snprintf( format_string, sizeof( format_string ), 
             _("Sunset: %s\n"), time_format );
          (void)g_string_append_printf(mboxes, format_string, H, M,
             ampm_letter(ampm_digit) );
@@ -976,14 +1019,14 @@ update_tooltip(Sun *sun)
 
          ampm_digit = clock_ampm( H );
          H = clock_adjust_hour( H );
-         (void)snprintf( format_string, sizeof(format_string), 
+         (void)g_snprintf( format_string, sizeof(format_string),
             _("Solar noon: %s\n"), time_format );
          (void)g_string_append_printf(mboxes, format_string, H, M,
             ampm_letter(ampm_digit) );
 
          /* Solar altitude at noon */
          altnoon = 90.0 - sun->data.Glat + sun->data.DEC_sun;
-         if ((altnoon - 90.0) > DBL_EPSILON) /* > */
+         if (altnoon > 90.0)
          {
             altnoon = 90.0 - (altnoon - 90.0);
          }
@@ -993,7 +1036,7 @@ update_tooltip(Sun *sun)
          /* Altitude now */
          val = (sun->data.LST - sun->data.LTRise) / dayLength(sun);
 
-         if ((val - 0.5) > DBL_EPSILON) /* > */
+         if (val > 0.5)
          {
             val = 1.0 - val;
          }
@@ -1001,11 +1044,33 @@ update_tooltip(Sun *sun)
          (void)g_string_append_printf(mboxes, _("\nClick to see Moon"));
       }
    } else {    /* Moon */
+#if 0
          (void)g_string_append_printf(mboxes, _("\nMoon Altitude: %4.1f"), sun->data.h_moon);
          (void)g_string_append_printf(mboxes, _("\nMoon Phase: %4.1f\n"), sun->data.MoonPhase);
          /* MoonPhase: 0 -> 1; there are 8 phase names */
          moonphase = (gint) ((sun->data.MoonPhase * 8.0) + 0.4);
          (void)g_string_append_printf(mboxes, _("Moon Phase: %s\n"), moonPhases[moonphase]);
+#else /* 0 */
+	 (void)g_string_append_printf(mboxes,
+	   _("Age: %2.2f Days\n"), sun->data.MoonAge);
+	 (void)g_string_append_printf(mboxes,
+	   _("Frac: %5.1f%%\n"), 100 * sun->data.MoonPhase);
+         /* MoonPhase: 0 -> 1; there are 8 phase names */
+         moonphase = (gint) ((sun->data.MoonPhase * 8.0) + 0.4);
+         (void)g_string_append_printf(mboxes,
+           _("Phase: %s\n"), moonPhases[moonphase]);
+	 (void)g_string_append_printf(mboxes,
+	   _("Illum: %5.1f%%\n"),
+	   50.0 * (1.0 - cos(sun->data.MoonPhase * M_PI * 2)));
+         (void)g_string_append_printf(mboxes, _("Altitude: %4.1f\n"),
+           sun->data.h_moon);
+	 (void)g_string_append_printf(mboxes, _("Visible: %s\n"),
+		 sun->data.Visible ? "Yes" : "No");
+	 (void)g_string_append(mboxes, _("- Rise and Set Times -\n"));
+	 show_moon_riseset_time(sun, -1, _("Yesterday"), mboxes);
+	 show_moon_riseset_time(sun, 0, _("Today"), mboxes);
+	 show_moon_riseset_time(sun, 1, _("Tomorrow"), mboxes);
+#endif /* 0 */
 
          (void)g_string_append_printf(mboxes, _("\nClick to see Sun"));
    }
@@ -1109,13 +1174,8 @@ static void getFontDimensions(gchar *text, gint *width, gint *height)
    gkrellm_text_extents(textOptions.timeStyles[UV_SUN][TIME_RISE]->font, text,
       (gint)strlen(text), width, height, &baseline, &y_ink);
 
-/*   g_message("%s width=%d height=%d baseline=%d y_ink=%d\n",text, *width, *height, baseline, y_ink);*/
-
    /* For now, we'll use the baseline as height. */
    *height = baseline;
-
-   if (options.debug) 
-      g_message("With the current font, %s is %d wide and %d high\n", text, *width, *height);
 }
 
 /* Given a font name (as a string), calculate gdkFont, x_offsets for
@@ -1134,8 +1194,6 @@ static void setFontInfo(void)
    textOptions.fontDesc = pango_font_description_from_string
       (textOptions.fontNames[FONT_NEW]);
       
-/*   g_message("%s %s\n", textOptions.fontNames[FONT_NEW],pango_font_description_to_string((const PangoFontDescription *)textOptions.fontNames[FONT_NEW]));*/
-
    if (textOptions.fontDesc == NULL)
    {
       g_message(_("FATAL Error : Could not get Pango font description for %s\n"),
@@ -1145,7 +1203,7 @@ static void setFontInfo(void)
    }
 
    /* If all is good, set NEW = CURRENT */
-   strncpy(textOptions.fontNames[FONT_CURRENT],
+   g_strlcpy(textOptions.fontNames[FONT_CURRENT],
       textOptions.fontNames[FONT_NEW], 128);
 
    for (time = 0; time < NUMBER_OF_TIMES; time++)
@@ -1373,7 +1431,7 @@ setTextFont_cb(/*@unused@*/GtkWidget *widget, /*@unused@*/GdkEventButton *ev, /*
    response = gtk_dialog_run(GTK_DIALOG(w));
    if (response == GTK_RESPONSE_OK)
    {
-      strncpy(textOptions.fontNames[FONT_NEW], gtk_font_selection_dialog_get_font_name((GtkFontSelectionDialog *)w), 128);
+      g_strlcpy(textOptions.fontNames[FONT_NEW], gtk_font_selection_dialog_get_font_name((GtkFontSelectionDialog *)w), 128);
    }
 
    gtk_widget_hide(w);
@@ -1542,6 +1600,7 @@ sun_create_tab(GtkWidget *tab_vbox)
    show90Path_button = gtk_check_button_new_with_label (_("Show apogee path"));
    showMiniMoon_button = gtk_check_button_new_with_label (_("Show mini-moon"));
    showETA_button = gtk_check_button_new_with_label (_("Show rise/set ETA"));
+   autoMoon_button = gtk_check_button_new_with_label (_("Change to moon at night"));
 
    gtk_table_attach((GtkTable *)table1, clock24_button, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
    gtk_table_attach((GtkTable *)table1, showStar_button, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
@@ -1549,12 +1608,14 @@ sun_create_tab(GtkWidget *tab_vbox)
    gtk_table_attach((GtkTable *)table1, show90Path_button, 1, 2, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
    gtk_table_attach((GtkTable *)table1, showETA_button, 2, 3, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
    gtk_table_attach((GtkTable *)table1, showMiniMoon_button, 2, 3, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
+   gtk_table_attach((GtkTable *)table1, autoMoon_button, 0, 1, 2, 3, GTK_FILL, GTK_FILL, 0, 0);
 
    gtk_toggle_button_set_active((GtkToggleButton *)clock24_button, options.clock24);
    gtk_toggle_button_set_active((GtkToggleButton *)showStar_button, options.showStar);
    gtk_toggle_button_set_active((GtkToggleButton *)showPath_button, options.showPath);
    gtk_toggle_button_set_active((GtkToggleButton *)show90Path_button, options.show90Path);
    gtk_toggle_button_set_active((GtkToggleButton *)showMiniMoon_button, options.showMiniMoon);
+   gtk_toggle_button_set_active((GtkToggleButton *)autoMoon_button, options.autoMoon);
    gtk_toggle_button_set_active((GtkToggleButton *)showETA_button, options.showETA);
 
    gkrellm_gtk_spin_button(vbox, &sunmoon_spin_button,
@@ -1574,10 +1635,11 @@ sun_create_tab(GtkWidget *tab_vbox)
       {
          N_("<b>GKrellM2 SunClock Plugin\n\n"),
          N_("<b>Click on the image to toggle the Sun/Moon view.\n\n"),
-         N_("<b>Longitude and Latitude:\n"),
-         N_("\tWorld\t: http://www.calle.com/world/\n" \
-         "\tUSA\t\t: http://www.census.gov/cgi-bin/gazetteer\n" \
-         "\tMore Sun/Moon info\t: http://www.wunderground.com\n"),
+         N_("<b>Latitude and Longitude:\n"),
+         N_("<ul>\tLatitude: N is +, S is -\t\tLongitude: E is -, W is +.\n"),
+         N_("\tWorld:\thttp://www.calle.com/world/\n" \
+         "\tUSA:\thttp://www.census.gov/cgi-bin/gazetteer\n" \
+         "\tInfo:\t\thttp://www.wunderground.com\n"),
          N_("<b>Use 24 hour clock:\n"),
          N_("\tdisplay sunrise/sunset using 24 hour clock\n"),
          N_("<b>Show star:\n"),
@@ -1587,9 +1649,11 @@ sun_create_tab(GtkWidget *tab_vbox)
          N_("\tuse dots to show the path of the sun across the sky\n"),
          N_("<b>Show apogee path:\n"),
          N_("\tuse dots to show the path the sun would take if it went\n" \
-         "\t through the zenith at solar noon (it's highest path).\n"),
+         "\t through the zenith at solar noon (its highest path).\n"),
          N_("<b>Show sun rise/set ETA:\n"),
          N_("\tshow ETA until sunrise/sunset below sunrise/sunset times\n"),
+         N_("<b>Change to moon at night:\n"),
+         N_("\tshow sun during day, moon after sunset.\n"),
       };
 
       vbox = gkrellm_gtk_notebook_page(tabs, _("Info"));
@@ -1608,12 +1672,13 @@ sun_create_tab(GtkWidget *tab_vbox)
       plugin_about_text = g_strdup_printf(
          _("SunClock %d.%d.%d\n" \
 	   "GKrellM2 SunClock Plugin\n" \
-	   "$Id: gkrellsun.c,v 1.59 2004/06/06 13:34:21 nwalsh Exp $\n\n" \
-	   "Copyright (C) 2001, 2002, 2003, 2004 Norman Walsh\n" \
+	   "$Id: gkrellsun.c,v 1.64 2006/03/17 13:29:51 nwalsh Exp $\n\n" \
+	   "Copyright (C) 2001, 2002, 2003, 2004, 2006 Norman Walsh\n" \
 	   "ndw@nwalsh.com\n\n" \
 	   "v0.10.0+ Additional code by Kurt V. Hindenburg\n" \
 	   "Copyright (C) 2004 Kurt V. Hindenburg\n" \
-	   "khindenburg@cherrynebula.net\n\n" \
+	   "public@kurt.hindenburg.name\n\n" \
+	   "v1.0.0+ Includes patches by Geoff Kuenning\n\n" \
 	   "Derived from MoonClock 0.3 Copyright (C) 2001 Dale P. Smith\n" \
 	   "and wmSun 1.03 Copyright (C) 1999 Mike Hnderson\n\n" \
 	   "Released under the GNU Public Licence"),
@@ -1638,6 +1703,7 @@ sun_apply_config()
    options.showPath = GTK_TOGGLE_BUTTON(showPath_button)->active;
    options.show90Path = GTK_TOGGLE_BUTTON(show90Path_button)->active;
    options.showMiniMoon = GTK_TOGGLE_BUTTON(showMiniMoon_button)->active;
+   options.autoMoon = GTK_TOGGLE_BUTTON(autoMoon_button)->active;
    options.showETA = GTK_TOGGLE_BUTTON(showETA_button)->active;
    options.debug = GTK_TOGGLE_BUTTON(debug_button)->active;
 
@@ -1724,6 +1790,8 @@ sun_apply_config()
    redraw = 1;
    panel_view = 0;      /* Force sun to panel */
    update_tooltip ( &sununit );
+
+   save_sun_data();
 }
 
 static GkrellmMonitor plugin_mon  =
@@ -1777,6 +1845,7 @@ gkrellm_init_plugin()
    options.show90Path = 0;                        /* Or the apogee path */
    options.showMiniMoon = 0;                      /* Or the mini moon */
    options.showETA = 0;                           /* Or the rise/set ETA */
+   options.autoMoon = 0;			  /* No auto sun/moon change */
    options.debug = 0;                             /* No debugging */
    options.whichSun = 0;
    options.sunmoon_toggle_minutes = 15;            /* Toggle every x minutes */
@@ -1796,13 +1865,13 @@ gkrellm_init_plugin()
          textOptions.timeColors[sun][time].green = 65535;
          textOptions.timeColors[sun][time].blue = 65535;
       }
-      strncpy(time_str[time],"      ",6);
+      g_strlcpy(time_str[time],"      ",6);
 
       /* 1st one is all the matters, starting y for TIME_RISE */
       textOptions.timeYOffsets[time] = 5;
    }
-   strncpy(textOptions.fontNames[FONT_CURRENT], "sans 8", 128);
-   strncpy(textOptions.fontNames[FONT_NEW], "sans 8", 128);
+   g_strlcpy(textOptions.fontNames[FONT_CURRENT], "sans 8", 128);
+   g_strlcpy(textOptions.fontNames[FONT_NEW], "sans 8", 128);
 
    colorsCreated = FALSE;
    textOptions.fontDesc = NULL;
@@ -1829,7 +1898,7 @@ load_sun_data(void)
    filename = g_build_filename(sun_data_dir, G_DIR_SEPARATOR_S, "sun", NULL);
 
    if (options.debug == TRUE)
-      g_message("Loading %s data from <%s>\n", PLUGIN_CONFIG_KEYWORD, filename);
+      g_message(_("Loading %s data from <%s>\n"), PLUGIN_CONFIG_KEYWORD, filename);
 
    if (g_file_test (filename, G_FILE_TEST_EXISTS) == FALSE) {
       g_message(_("gkrellsun : Data file doesn't exist! %s\n"), filename);
@@ -1886,6 +1955,8 @@ load_sun_data(void)
          options.showMiniMoon=(int)g_ascii_strtoull(entry[1], NULL, 10);
       } else if (g_str_has_prefix(entry[0], "showeta")) {
          options.showETA=(int)g_ascii_strtoull(entry[1], NULL, 10);
+      } else if (g_str_has_prefix(entry[0], "autoMoon")) {
+         options.autoMoon=(int)g_ascii_strtoull(entry[1], NULL, 10);
       } else if (g_str_has_prefix(entry[0], "toggleminutes")) {
          options.sunmoon_toggle_minutes=(int)g_ascii_strtoull(entry[1], NULL, 10);
       } else if (g_str_has_prefix(entry[0], "sun")) {
@@ -1924,7 +1995,7 @@ save_sun_data(void)
    filename = g_build_filename(sun_data_dir, G_DIR_SEPARATOR_S, "sun", NULL);
 
    if (options.debug == TRUE)
-      g_message("Saving %s to <%s>\n", PLUGIN_CONFIG_KEYWORD, filename);
+      g_message(_("Saving %s to <%s>\n"), PLUGIN_CONFIG_KEYWORD, filename);
 
    if ((f = fopen(filename, "w")) == NULL) {
       g_message(_("gkrellsun : Unable to save data to %s!\n"), filename);
@@ -1940,6 +2011,7 @@ save_sun_data(void)
    fprintf(f, "show90path=%d\n", options.show90Path);
    fprintf(f, "showMiniMoon=%d\n", options.showMiniMoon);
    fprintf(f, "showeta=%d\n", options.showETA);
+   fprintf(f, "autoMoon=%d\n", options.autoMoon);
    fprintf(f, "debug=%d\n", options.debug);
 
    fprintf(f, "font=%s\n", textOptions.fontNames[FONT_CURRENT]);
